@@ -1,10 +1,10 @@
 from .s3_memoize import *
 
 __copyright__    = 'Copyright 2020 Susumu OTA'
-__version__      = '0.1.0'
+__version__      = '0.1.1'
 __license__      = 'Apache License 2.0'
 __author__       = 'Susumu OTA'
-__author_email__ = 'ota.s.research@gmail.com'
+__author_email__ = 'ota.s.research@example.com'
 __url__          = 'https://github.com/susumuota/s3_memoize'
 
 __all__ = ['s3_memoize']
